<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Show YouTube movies in chat window</source>
        <translation>Show YouTube movies in chat window</translation>
    </message>
    <message>
        <source>Show images in chat window</source>
        <translation>Show images in chat window</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
</context>
</TS>
